@@ -66,11 +66,7 @@ def _error_handler(result, fn, args):
         raise RuntimeError("unexpected return value: %s" % result)
     return result
 
-_soabi = ""
-if sysconfig.get_config_var("SOABI"):
-    _soabi = ".%s" % sysconfig.get_config_var("SOABI")
-
-_libsuinput_path = os.path.abspath(os.path.join(os.path.dirname(__file__), "..", "_libsuinput" + _soabi + sysconfig.get_config_var("SO")))
+_libsuinput_path = os.path.abspath(os.path.join(os.path.dirname(__file__), "..", "_libsuinput" + sysconfig.get_config_var("SO")))
 _libsuinput = ctypes.CDLL(_libsuinput_path, use_errno=True)
 _libsuinput.suinput_open.errcheck = _error_handler
 _libsuinput.suinput_enable_event.errcheck = _error_handler
